!---------------------------------------------------------------------------------------
! GRID_TO_NCDF: factor_convert
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> factor_convert
!! 
!! Purpose:    
!!
!---------------------------------------------------------------------------------------

subroutine factor_convert(files, config, nr, timestamp)

  use mod_var
  use mod_settings
  use mod_flexpart
  use mod_dates

  implicit none

  type (files_t),  intent(in out)        :: files
  type (config_t), intent(in)            :: config
  integer,         intent(in)            :: nr
  integer,         intent(in)            :: timestamp

  character(max_path_len)                                :: filename, filedates, path_flexpart, path_output
  character(len=8)                                       :: adate
  character(len=6)                                       :: atime
  logical                                                :: lexist
  integer                                                :: nfiles, nread, i, ierr, n
  integer                                                :: jjjjmmdd, hhmiss 
  real, dimension(:,:,:), allocatable                    :: grid
  real(kind=8), dimension(:), allocatable                :: ftime, dates
  real(kind=8)                                           :: jdate

  ! path names 
  if ( trim(config%filefreq).eq.'month' ) then
    write(adate,'(I6.6)') timestamp/100
    print*, adate
  else if ( trim(config%filefreq).eq.'day' ) then
    write(adate,'(I8.8)') timestamp
  endif
  path_flexpart = trim(files%path_flexpart)//trim(recname(nr))//'/'//trim(adate)//'/'
  path_output = trim(files%path_output)//trim(recname(nr))//'/'
  filedates = trim(path_flexpart)//'dates'

  ! read binary file
  call get_nread(filedates, nread)
  allocate ( dates(nread) )
  allocate ( ftime(nread) )
  allocate ( grid(nxgrid,nygrid,nread) )
  call read_dates(filedates, nread, dates)
  do n = 1, nread
    ftime(n) = juldate(int(dates(n)/1d6),int(dates(n)-floor(dates(n)/1d6)*1d6)) 
  end do
  grid(:,:,:) = 1. 
  if ( config%lnested ) then
    filename = trim(path_flexpart)//'factor_drygrid_nest'
  else
    filename = trim(path_flexpart)//'factor_drygrid'
  endif
  inquire ( file=trim(filename),exist=lexist )
  if ( lexist ) then
    write(*,*) 'Reading correction factor :'//trim(filename)
    call read_factor(filename, nread, nxgrid, nygrid, nxshift, grid)
  endif

  ! output file name
  if ( config%lnested ) then
    filename = trim(path_output)//'factor_drygrid_nest.nc'
  else
    filename = trim(path_output)//'factor_drygrid.nc'
  endif

  ! write as ncdf
  call write_ncdf(config, filename, ftime, grid)

  deallocate( grid )
  deallocate( ftime )
  deallocate( dates )

end subroutine factor_convert

